﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Menus;
using Infragistics.DragDrop;

namespace DDBetweenTrees
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            xamDataTree1.ItemsSource = new ContinentCollection();
            xamDataTree2.ItemsSource = new ContinentCollection();
        }

        private void XamDataTree_NodeDragDrop(object sender, TreeDropEventArgs e)
        {
            if (e.DragDropEventArgs.OperationType == OperationType.Copy)
            {
                XamDataTreeNode dropNode = (e.DragDropEventArgs.DropTarget as XamDataTreeNodeControl).Node;
                Continent dragData = (e.DragDropEventArgs.DragSource as XamDataTreeNodeControl).Node.Data as Continent;

                if (dropNode != null && dragData != null)
                {
                    dropNode.Nodes.Add(
                        new XamDataTreeNode(dropNode.Index + 1, dropNode.Manager,
                            new Continent
                            {
                                Name = dragData.Name,
                                Children = dragData.Children
                            },
                            false,
                            dropNode.NodeLayout));
                }
            }
        }
    }

    #region Data
    public class ContinentCollection : ObservableCollection<Continent>
    {
        public ContinentCollection()
        {
            Add(
                new Continent
                {
                    Name = "Africa",
                    Children = new ObservableCollection<Continent>()
                    {
                        new Continent()
                        {
                            Name = "Algeria",
                            Children = new ObservableCollection<Continent>()
                            {
                                new Continent {Name = "Algiers"},
                                new Continent {Name = "Oran"},
                            }
                        },
                        new Continent()
                        {
                            Name = "Angola",
                            Children = new ObservableCollection<Continent>()
                            {
                                new Continent {Name = "Soyo"},
                                new Continent {Name = "Ndalatando"},
                                new Continent {Name = "Ambriz"},
                            }
                        },
                        new Continent()
                        {
                            Name = "Cape Verde",
                            Children = new ObservableCollection<Continent>()
                            {
                                new Continent {Name = "Mindelo"},
                                new Continent {Name = "Assomada"},
                            }
                        }
                    }
                });

            Add(
                new Continent
                {
                    Name = "Asia",
                    Children = new ObservableCollection<Continent>()
                                    {
                                        new Continent()
                                        {
                                            Name = "Cambodia",
                                            Children = new ObservableCollection<Continent>()
                                            {
                                                new Continent {Name = "Phnom Penh"},
                                                new Continent {Name = "Koh Kong"},
                                            }
                                        },
                                        new Continent()
                                        {
                                            Name = "China",
                                            Children = new ObservableCollection<Continent>()
                                            {
                                                new Continent {Name = "Shanghai"},
                                                new Continent {Name = "Beijing"},
                                                new Continent {Name = "Tianjin"},
                                            }
                                        },
                                        new Continent()
                                        {
                                            Name = "Japan",
                                            Children = new ObservableCollection<Continent>()
                                            {
                                                new Continent {Name = "Tokyo"},
                                                new Continent {Name = "Yokohama"},
                                                new Continent {Name = "Sapporo"},
                                            }
                                        }
                                    }
                });

            Add(new Continent
            {
                Name = "Australia",
                Children = new ObservableCollection<Continent>()
                                    {
                                        new Continent()
                                        {
                                            Name = "Australia",
                                            Children = new ObservableCollection<Continent>()
                                            {
                                                new Continent {Name = "Sydney"},
                                                new Continent {Name = "Melbourne"},
                                                new Continent {Name = "Perth"},
                                            }
                                        }
                                    }
            });

            Add(new Continent
            {
                Name = "Europe",
                Children = new ObservableCollection<Continent>()
                                    {
                                        new Continent()
                                        {
                                            Name = "Germany",
                                            Children = new ObservableCollection<Continent>()
                                            {
                                                new Continent {Name = "Berlin"},
                                                new Continent {Name = "Hamburg"}
                                            }
                                        },
                                        new Continent()
                                        {
                                            Name = "Italy",
                                            Children = new ObservableCollection<Continent>()
                                            {
                                                new Continent {Name = "Milan"},
                                                new Continent {Name = "Naples"},
                                                new Continent {Name = "Rome"}
                                            }
                                        }
                                    }
            });
        }
    }

    public class Continent
    {
        public string Name { get; set; }
        public ObservableCollection<Continent> Children { get; set; }
    }

    #endregion
}
